Autoscaling in Axes3D
~~~~~~~~~~~~~~~~~~~~~

In Matplotlib 3.2.0, autoscaling was made lazier for 2D Axes, i.e., limits
would only be recomputed when actually rendering the canvas, or when the user
queries the Axes limits. This performance improvement is now extended to
`.Axes3D`. This also fixes some issues with autoscaling being triggered
unexpectedly in Axes3D.

Please see :ref:`the API change for 2D Axes <api-changes-3-2-0-autoscaling>`
for further details.
